@@ -20,7 +20,10 @@ class ConexaoBanco():
         self.port=3306
         self.ssl_verify_cert=True
 
-        self.ssl_ca= os.getcwd() + "\\ingestao\\banco_dados\\ssl_ca_file\\iotbd.crt.pem"
+        #self.ssl_ca= os.getcwd() + "\\ingestion\\ingestion\\banco_dados\\ssl_ca_file\\iotbd.crt.pem"
+
+        self.ssl_ca= os.path.dirname(__file__) + "\\ssl_ca_file\\iotbd.crt.pem"
+
 
         self.db_url = f'mysql+mysqlconnector://{self.user}:{self.password}@{self.host}:{self.port}/{self.database}'
 
