@@ -57,7 +57,7 @@ class Start():
                 logging.info(f"Final o processo simples\n")
                 
             except Exception as error:
-                raise Exception(f"Erro no processamento {error}")
+                raise Exception(f"{error}")
 
         else:
 
@@ -85,7 +85,7 @@ class Start():
 
                     count = count + 1    
                 except Exception as error:
-                    raise Exception(f"Erro no processamento {error}")
+                    raise Exception(f"{error}")
 
         del(df_data)
 
@@ -130,7 +130,7 @@ class Start():
                 del(self.dados)
 
         except Exception as error:
-            raise Exception(f"Erro no processamento {error}")
+            raise Exception(f"{error}")
 
     def __copy_input_enrichment(self):
 
@@ -437,16 +437,16 @@ class Start():
             self.start()   
             self.enrichment(myDict)
             self.backup()
-            logging.info(f"processamento finalizado com sucesso arquivo {self.path_file}")
-            msg = f"processamento finalizado com sucesso arquivo {self.path_file}"
+            logging.info(f"Processamento finalizado com sucesso arquivo {self.path_file}")
+            msg = msg + f"\nProcessamento finalizado com sucesso arquivo {self.path_file}. "
         except Exception as e:
             logging.error(f"Falha no processo {e}")
-            msg = f"Falha no processo {e}"
+            msg = msg +  f"\nFalha no processo {e}. "
             self.fail()
         finally:
             self.__close_base()
             logging.info("Fim do processo")
-            msg = "Fim do processo"
+            msg = msg + "\nFim do processo. "
 
         return msg
 
